==> nextcloud-app-calendar-1:5.5.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lb.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Prost!",
    "Calendar" : "Kalenner",
    "Confirm" : "Konfirméieren",
    "Location:" : "Uert:",
    "Today" : "Haut",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Copy link" : "Link kopéieren",
    "Edit" : "Änneren",
    "Delete" : "Läschen",
    "Calendars" : "Kalenneren",
    "New calendar" : "Neie Kalenner",
    "Export" : "Exportéieren",
    "Empty trash bin" : "Eidel Dreckskëscht",
    "Name" : "Numm",
    "Deleted" : "Geläscht",
    "Restore" : "Zrécksetzen",
    "Delete permanently" : "Permanent läschen",
    "Hidden" : "Verstoppt",
    "Share link" : "Link deelen",
    "can edit" : "kann änneren",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "Save" : "Späicheren",
    "Cancel" : "Ofbriechen",
    "Automatic" : "Automatesch",
    "List view" : "Lëscht Vue",
    "Actions" : "Aktiounen",
    "Update" : "Update",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "to" : "bis",
    "Add" : "Derbäimaachen",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sunday" : "Sonndeg",
    "Your email address" : "Deng Email Adress",
    "Email" : "Email",
    "seconds" : "Sekonnen",
    "minutes" : "Minutten",
    "hours" : "Stonnen",
    "days" : "Deeg",
    "weeks" : "Wochen",
    "Unknown" : "Onbekannt",
    "Attendees" : "Participanten",
    "Repeat" : "Widderhuelen",
    "never" : "Ni",
    "after" : "No",
    "Global" : "Global",
    "Subscribe" : "Umellen",
    "Personal" : "Perséinlech",
    "Edit event" : "Evenement änneren",
    "Close" : "Zoumaachen",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "second" : "zweet",
    "Other" : "Aner",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1:6.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lb.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Prost!",
    "Calendar" : "Kalenner",
    "Confirm" : "Konfirméieren",
    "Location:" : "Uert:",
    "Today" : "Haut",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Copy link" : "Link kopéieren",
    "Edit" : "Änneren",
    "Delete" : "Läschen",
    "Calendars" : "Kalenneren",
    "New calendar" : "Neie Kalenner",
    "Export" : "Exportéieren",
    "Empty trash bin" : "Eidel Dreckskëscht",
    "Name" : "Numm",
    "Deleted" : "Geläscht",
    "Restore" : "Zrécksetzen",
    "Delete permanently" : "Permanent läschen",
    "Share link" : "Link deelen",
    "can edit" : "kann änneren",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "Save" : "Späicheren",
    "Cancel" : "Ofbriechen",
    "Automatic" : "Automatesch",
    "List view" : "Lëscht Vue",
    "Actions" : "Aktiounen",
    "General" : "Allgemeng",
    "Update" : "Update",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "to" : "bis",
    "Add" : "Derbäimaachen",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sunday" : "Sonndeg",
    "Your email address" : "Deng Email Adress",
    "Email" : "Email",
    "seconds" : "Sekonnen",
    "minutes" : "Minutten",
    "hours" : "Stonnen",
    "days" : "Deeg",
    "weeks" : "Wochen",
    "Unknown" : "Onbekannt",
    "Attendees" : "Participanten",
    "Repeat" : "Widderhuelen",
    "never" : "Ni",
    "after" : "No",
    "Yes" : "Jo",
    "No" : "Nee",
    "None" : "Keng",
    "Global" : "Global",
    "Subscribe" : "Umellen",
    "Personal" : "Perséinlech",
    "Edit event" : "Evenement änneren",
    "Close" : "Zoumaachen",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "second" : "zweet",
    "Other" : "Aner",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Hidden" : "Verstoppt"
},
"nplurals=2; plural=(n != 1);");
